==> ejc-zdsmaterialb-api-3.0.0-20240802.102206-4-sources.jar: com/ejianc/business/zdsmaterial/plan/purchase/vo/PurchasePlanVO.java <==
package com.ejianc.business.zdsmaterial.plan.purchase.vo;

import java.util.Date;
import java.util.List;
import java.util.ArrayList;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;

/**
 * 采购计划
 * 
 * @author generator
 * 
 */
public class PurchasePlanVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private Long orgId; // 单据组织id
    private String orgName; // 单据组织名称
    private String orgCode; // 单据组织编码
    private Long parentOrgId; // 上级组织id
    private String parentOrgName; // 上级组织名称
    private String parentOrgCode; // 上级组织编码
    private Long projectId; // 项目id
    private String projectName; // 项目名称
    private String projectCode; // 项目编码
    private String billCode; // 单据编码
    private Integer billState; // 单据状态
    private Long engineerId; // 主责工程师id
    private String engineerName; // 主责工程师name
    private String engineerCode; // 主责工程师code
    private Long projectManagerId; // 项目经理id
    private String projectManagerName; // 项目经理
    private String projectManagerCode; // 项目经理
    private Long chiefEngineerId; // 项目总工id
    private String chiefEngineerName; // 项目总工name
    private String chiefEngineerCode; // 项目总工code
    private String planName; // 计划名称
    private String compileName; // 编制人name
    private Integer excessFlag; // 是否存在超量明细 1：是； 0：否 超量审批用
    private Integer newMatFlag; // 是否有新增材料编码：0-否，1-是
    private Integer pushStatus; // 推送状态：0-否，1-是
    private String memo; // 备注
    private String commitFlag;//是否不可以提交  true
    private String createUserName;// 编制者名称
    private String billStateName; // 单据状态名称
    private Integer excessStatus; //         {"1 仅提示", " 2 超量审批", " 3 不可提交"};
    private Integer hasNewPropertyVal;
    private Long purchaseWorkerId; // 采购工程师
    private String purchaseWorkerName; // 采购工程师
    private Long jobSpecialtyId; // 工作专业
    private String jobSpecialtyName; // 工作专业`
    private String jobSpecialtyCode; // 工作专业

    private Long commitUserId; // 提交人主键
    private String commitUserName; // 提交人名称
    private String commitUserCode; // 提交人编码
    private Long approveUserId; // 提交人主键
    private String approveUserName; // 提交人名称
    private String approveUserCode; // 提交人编码

    private Date commitDate; // 提交日期
    private Date effectDate; // 生效日期
    private String userPostName;// 编制者岗位
    private String userDepartName;// 编制者部门
    private String userOrgName;// 编制者组织
    private Long createUserId; // 创建人id
    private String commitUserSid; // 提交人s主键
    private String projectManagerSid; // 项目经理sid
    private String chiefEngineerSid; // 项目总工sid
    private String purchaseWorkerSid; // 采购工程师sid
    private String approveUserSid; // 审批人sid
    private String createUserSid; // 创建人sid
    private String businessContractId; // 商务合同id
    private String businessContractName; // 商务合同name
    private String businessContractCode; // 商务合同code
    private String projectSid;//项目来源id
    private Integer excessBpmFlag; // 是否超量审批 1：是； 0：否 超量审批用

    public Integer getExcessBpmFlag() {
        return excessBpmFlag;
    }

    public void setExcessBpmFlag(Integer excessBpmFlag) {
        this.excessBpmFlag = excessBpmFlag;
    }

    public String getJobSpecialtyCode() {
        return jobSpecialtyCode;
    }

    public void setJobSpecialtyCode(String jobSpecialtyCode) {
        this.jobSpecialtyCode = jobSpecialtyCode;
    }

    public String getProjectSid() {
        return projectSid;
    }

    public void setProjectSid(String projectSid) {
        this.projectSid = projectSid;
    }

    public String getBusinessContractId() {
        return businessContractId;
    }

    public void setBusinessContractId(String businessContractId) {
        this.businessContractId = businessContractId;
    }

    public String getBusinessContractName() {
        return businessContractName;
    }

    public void setBusinessContractName(String businessContractName) {
        this.businessContractName = businessContractName;
    }

    public String getBusinessContractCode() {
        return businessContractCode;
    }

    public void setBusinessContractCode(String businessContractCode) {
        this.businessContractCode = businessContractCode;
    }

    public Long getCreateUserId() {
        return createUserId;
    }

    public void setCreateUserId(Long createUserId) {
        this.createUserId = createUserId;
    }

    public String getCommitUserSid() {
        return commitUserSid;
    }

    public void setCommitUserSid(String commitUserSid) {
        this.commitUserSid = commitUserSid;
    }

    public String getProjectManagerSid() {
        return projectManagerSid;
    }

    public void setProjectManagerSid(String projectManagerSid) {
        this.projectManagerSid = projectManagerSid;
    }

    public String getChiefEngineerSid() {
        return chiefEngineerSid;
    }

    public void setChiefEngineerSid(String chiefEngineerSid) {
        this.chiefEngineerSid = chiefEngineerSid;
    }

    public String getPurchaseWorkerSid() {
        return purchaseWorkerSid;
    }

    public void setPurchaseWorkerSid(String purchaseWorkerSid) {
        this.purchaseWorkerSid = purchaseWorkerSid;
    }

    public String getApproveUserSid() {
        return approveUserSid;
    }

    public void setApproveUserSid(String approveUserSid) {
        this.approveUserSid = approveUserSid;
    }

    public String getCreateUserSid() {
        return createUserSid;
    }

    public void setCreateUserSid(String createUserSid) {
        this.createUserSid = createUserSid;
    }

    public String getUserPostName() {
        return userPostName;
    }

    public void setUserPostName(String userPostName) {
        this.userPostName = userPostName;
    }

    public String getUserDepartName() {
        return userDepartName;
    }

    public void setUserDepartName(String userDepartName) {
        this.userDepartName = userDepartName;
    }

    public String getUserOrgName() {
        return userOrgName;
    }

    public void setUserOrgName(String userOrgName) {
        this.userOrgName = userOrgName;
    }

    public Long getCommitUserId() {
        return commitUserId;
    }

    public void setCommitUserId(Long commitUserId) {
        this.commitUserId = commitUserId;
    }

    public String getCommitUserName() {
        return commitUserName;
    }

    public void setCommitUserName(String commitUserName) {
        this.commitUserName = commitUserName;
    }

    public String getCommitUserCode() {
        return commitUserCode;
    }

    public void setCommitUserCode(String commitUserCode) {
        this.commitUserCode = commitUserCode;
    }

    public Long getApproveUserId() {
        return approveUserId;
    }

    public void setApproveUserId(Long approveUserId) {
        this.approveUserId = approveUserId;
    }

    public String getApproveUserName() {
        return approveUserName;
    }

    public void setApproveUserName(String approveUserName) {
        this.approveUserName = approveUserName;
    }

    public String getApproveUserCode() {
        return approveUserCode;
    }

    public void setApproveUserCode(String approveUserCode) {
        this.approveUserCode = approveUserCode;
    }

    public Date getCommitDate() {
        return commitDate;
    }

    public void setCommitDate(Date commitDate) {
        this.commitDate = commitDate;
    }

    public Date getEffectDate() {
        return effectDate;
    }

    public void setEffectDate(Date effectDate) {
        this.effectDate = effectDate;
    }

    @ReferSerialTransfer(referCode="idm-employee")
    public Long getPurchaseWorkerId() {
        return purchaseWorkerId;
    }
    @ReferDeserialTransfer
    public void setPurchaseWorkerId(Long purchaseWorkerId) {
        this.purchaseWorkerId = purchaseWorkerId;
    }

    public String getPurchaseWorkerName() {
        return purchaseWorkerName;
    }

    public void setPurchaseWorkerName(String purchaseWorkerName) {
        this.purchaseWorkerName = purchaseWorkerName;
    }
    @ReferSerialTransfer(referCode = "support-defdoc")
    public Long getJobSpecialtyId() {
        return jobSpecialtyId;
    }
    @ReferDeserialTransfer
    public void setJobSpecialtyId(Long jobSpecialtyId) {
        this.jobSpecialtyId = jobSpecialtyId;
    }

    public String getJobSpecialtyName() {
        return jobSpecialtyName;
    }

    public void setJobSpecialtyName(String jobSpecialtyName) {
        this.jobSpecialtyName = jobSpecialtyName;
    }

    public Integer getHasNewPropertyVal() {
        return hasNewPropertyVal;
    }

    public void setHasNewPropertyVal(Integer hasNewPropertyVal) {
        this.hasNewPropertyVal = hasNewPropertyVal;
    }

    public Integer getExcessStatus() {
        return excessStatus;
    }

    public void setExcessStatus(Integer excessStatus) {
        this.excessStatus = excessStatus;
    }

    public String getBillStateName() {
        return billStateName;
    }

    public void setBillStateName(String billStateName) {
        this.billStateName = billStateName;
    }

    public String getCommitFlag() {
        return commitFlag;
    }

    public void setCommitFlag(String commitFlag) {
        this.commitFlag = commitFlag;
    }

    @Override
    public String getCreateUserName() {
        return createUserName;
    }

    public void setCreateUserName(String createUserName) {
        this.createUserName = createUserName;
    }

    private List<PurchasePlanDetailVO> detailList = new ArrayList<>(); // 采购计划详情
    @ReferSerialTransfer(referCode="idm-org")
    public Long getOrgId() {
        return orgId;
    }
    @ReferDeserialTransfer
    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }
    @ReferDeserialTransfer
    public Long getParentOrgId() {
        return parentOrgId;
    }

    public void setParentOrgId(Long parentOrgId) {
        this.parentOrgId = parentOrgId;
    }
    public String getParentOrgName() {
        return parentOrgName;
    }

    public void setParentOrgName(String parentOrgName) {
        this.parentOrgName = parentOrgName;
    }
    public String getParentOrgCode() {
        return parentOrgCode;
    }

    public void setParentOrgCode(String parentOrgCode) {
        this.parentOrgCode = parentOrgCode;
    }
    @ReferSerialTransfer(referCode="project-set")
    public Long getProjectId() {
        return projectId;
    }
    @ReferDeserialTransfer
    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public String getProjectCode() {
        return projectCode;
    }

    public void setProjectCode(String projectCode) {
        this.projectCode = projectCode;
    }
    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    @ReferSerialTransfer(referCode="idm-employee")
    public Long getEngineerId() {
        return engineerId;
    }
    @ReferDeserialTransfer
    public void setEngineerId(Long engineerId) {
        this.engineerId = engineerId;
    }
    public String getEngineerName() {
        return engineerName;
    }

    public void setEngineerName(String engineerName) {
        this.engineerName = engineerName;
    }
    public String getEngineerCode() {
        return engineerCode;
    }

    public void setEngineerCode(String engineerCode) {
        this.engineerCode = engineerCode;
    }
    @ReferSerialTransfer(referCode="idm-employee")
    public Long getProjectManagerId() {
        return projectManagerId;
    }
    @ReferDeserialTransfer
    public void setProjectManagerId(Long projectManagerId) {
        this.projectManagerId = projectManagerId;
    }
    public String getProjectManagerName() {
        return projectManagerName;
    }

    public void setProjectManagerName(String projectManagerName) {
        this.projectManagerName = projectManagerName;
    }
    public String getProjectManagerCode() {
        return projectManagerCode;
    }

    public void setProjectManagerCode(String projectManagerCode) {
        this.projectManagerCode = projectManagerCode;
    }
    @ReferSerialTransfer(referCode="idm-employee")
    public Long getChiefEngineerId() {
        return chiefEngineerId;
    }
    @ReferDeserialTransfer
    public void setChiefEngineerId(Long chiefEngineerId) {
        this.chiefEngineerId = chiefEngineerId;
    }
    public String getChiefEngineerName() {
        return chiefEngineerName;
    }

    public void setChiefEngineerName(String chiefEngineerName) {
        this.chiefEngineerName = chiefEngineerName;
    }
    public String getChiefEngineerCode() {
        return chiefEngineerCode;
    }

    public void setChiefEngineerCode(String chiefEngineerCode) {
        this.chiefEngineerCode = chiefEngineerCode;
    }
    public String getPlanName() {
        return planName;
    }

    public void setPlanName(String planName) {
        this.planName = planName;
    }
    public String getCompileName() {
        return compileName;
    }

    public void setCompileName(String compileName) {
        this.compileName = compileName;
    }
    public Integer getExcessFlag() {
        return excessFlag;
    }

    public void setExcessFlag(Integer excessFlag) {
        this.excessFlag = excessFlag;
    }
    public Integer getNewMatFlag() {
        return newMatFlag;
    }

    public void setNewMatFlag(Integer newMatFlag) {
        this.newMatFlag = newMatFlag;
    }
    public Integer getPushStatus() {
        return pushStatus;
    }

    public void setPushStatus(Integer pushStatus) {
        this.pushStatus = pushStatus;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    
     public List<PurchasePlanDetailVO> getDetailList() {
        return detailList;
     }

     public void setDetailList(List<PurchasePlanDetailVO> detailList) {
        this.detailList = detailList;
     }
}

==> ejc-zdsmaterialb-api-3.0.0-20241114.025133-43-sources.jar: com/ejianc/business/zdsmaterial/plan/purchase/vo/PurchasePlanVO.java <==
package com.ejianc.business.zdsmaterial.plan.purchase.vo;

import java.util.Date;
import java.util.List;
import java.util.ArrayList;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;

/**
 * 采购计划
 * 
 * @author generator
 * 
 */
public class PurchasePlanVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private Long orgId; // 单据组织id
    private String orgName; // 单据组织名称
    private String orgCode; // 单据组织编码
    private Long parentOrgId; // 上级组织id
    private String parentOrgName; // 上级组织名称
    private String parentOrgCode; // 上级组织编码
    private Long projectId; // 项目id
    private String projectName; // 项目名称
    private String projectCode; // 项目编码
    private String billCode; // 单据编码
    private Integer billState; // 单据状态
    private Long engineerId; // 主责工程师id
    private String engineerName; // 主责工程师name
    private String engineerCode; // 主责工程师code
    private Long projectManagerId; // 项目经理id
    private String projectManagerName; // 项目经理
    private String projectManagerCode; // 项目经理
    private Long chiefEngineerId; // 项目总工id
    private String chiefEngineerName; // 项目总工name
    private String chiefEngineerCode; // 项目总工code
    private String planName; // 计划名称
    private String compileName; // 编制人name
    private Integer excessFlag; // 是否存在超量明细 1：是； 0：否 超量审批用
    private Integer newMatFlag; // 是否有新增材料编码：0-否，1-是
    private Integer pushStatus; // 推送状态：0-否，1-是
    private String memo; // 备注
    private String commitFlag;//是否不可以提交  true
    private String createUserName;// 编制者名称
    private String billStateName; // 单据状态名称
    private Integer excessStatus; //         {"1 仅提示", " 2 超量审批", " 3 不可提交"};
    private Integer hasNewPropertyVal;
    private Long purchaseWorkerId; // 采购工程师
    private String purchaseWorkerName; // 采购工程师
    private Long jobSpecialtyId; // 工作专业
    private String jobSpecialtyName; // 工作专业`
    private String jobSpecialtyCode; // 工作专业

    private Long commitUserId; // 提交人主键
    private String commitUserName; // 提交人名称
    private String commitUserCode; // 提交人编码
    private Long approveUserId; // 提交人主键
    private String approveUserName; // 提交人名称
    private String approveUserCode; // 提交人编码

    private Date commitDate; // 提交日期
    private Date effectDate; // 生效日期
    private String userPostName;// 编制者岗位
    private String userDepartName;// 编制者部门
    private String userOrgName;// 编制者组织
    private Long createUserId; // 创建人id
    private String commitUserSid; // 提交人s主键
    private String projectManagerSid; // 项目经理sid
    private String chiefEngineerSid; // 项目总工sid
    private String purchaseWorkerSid; // 采购工程师sid
    private String approveUserSid; // 审批人sid
    private String createUserSid; // 创建人sid
    private String businessContractId; // 商务合同id
    private String businessContractName; // 商务合同name
    private String businessContractCode; // 商务合同code
    private String projectSid;//项目来源id
    private Integer excessBpmFlag; // 是否超量审批 1：是； 0：否 超量审批用

    private String budgetVer; //采购计划所属项目管控方式：0-费用包控制，1-清单管控281905，2-切包管控

    public String getBudgetVer() {
        return budgetVer;
    }

    public void setBudgetVer(String budgetVer) {
        this.budgetVer = budgetVer;
    }

    public Integer getExcessBpmFlag() {
        return excessBpmFlag;
    }

    public void setExcessBpmFlag(Integer excessBpmFlag) {
        this.excessBpmFlag = excessBpmFlag;
    }

    public String getJobSpecialtyCode() {
        return jobSpecialtyCode;
    }

    public void setJobSpecialtyCode(String jobSpecialtyCode) {
        this.jobSpecialtyCode = jobSpecialtyCode;
    }

    public String getProjectSid() {
        return projectSid;
    }

    public void setProjectSid(String projectSid) {
        this.projectSid = projectSid;
    }

    public String getBusinessContractId() {
        return businessContractId;
    }

    public void setBusinessContractId(String businessContractId) {
        this.businessContractId = businessContractId;
    }

    public String getBusinessContractName() {
        return businessContractName;
    }

    public void setBusinessContractName(String businessContractName) {
        this.businessContractName = businessContractName;
    }

    public String getBusinessContractCode() {
        return businessContractCode;
    }

    public void setBusinessContractCode(String businessContractCode) {
        this.businessContractCode = businessContractCode;
    }

    public Long getCreateUserId() {
        return createUserId;
    }

    public void setCreateUserId(Long createUserId) {
        this.createUserId = createUserId;
    }

    public String getCommitUserSid() {
        return commitUserSid;
    }

    public void setCommitUserSid(String commitUserSid) {
        this.commitUserSid = commitUserSid;
    }

    public String getProjectManagerSid() {
        return projectManagerSid;
    }

    public void setProjectManagerSid(String projectManagerSid) {
        this.projectManagerSid = projectManagerSid;
    }

    public String getChiefEngineerSid() {
        return chiefEngineerSid;
    }

    public void setChiefEngineerSid(String chiefEngineerSid) {
        this.chiefEngineerSid = chiefEngineerSid;
    }

    public String getPurchaseWorkerSid() {
        return purchaseWorkerSid;
    }

    public void setPurchaseWorkerSid(String purchaseWorkerSid) {
        this.purchaseWorkerSid = purchaseWorkerSid;
    }

    public String getApproveUserSid() {
        return approveUserSid;
    }

    public void setApproveUserSid(String approveUserSid) {
        this.approveUserSid = approveUserSid;
    }

    public String getCreateUserSid() {
        return createUserSid;
    }

    public void setCreateUserSid(String createUserSid) {
        this.createUserSid = createUserSid;
    }

    public String getUserPostName() {
        return userPostName;
    }

    public void setUserPostName(String userPostName) {
        this.userPostName = userPostName;
    }

    public String getUserDepartName() {
        return userDepartName;
    }

    public void setUserDepartName(String userDepartName) {
        this.userDepartName = userDepartName;
    }

    public String getUserOrgName() {
        return userOrgName;
    }

    public void setUserOrgName(String userOrgName) {
        this.userOrgName = userOrgName;
    }

    public Long getCommitUserId() {
        return commitUserId;
    }

    public void setCommitUserId(Long commitUserId) {
        this.commitUserId = commitUserId;
    }

    public String getCommitUserName() {
        return commitUserName;
    }

    public void setCommitUserName(String commitUserName) {
        this.commitUserName = commitUserName;
    }

    public String getCommitUserCode() {
        return commitUserCode;
    }

    public void setCommitUserCode(String commitUserCode) {
        this.commitUserCode = commitUserCode;
    }

    public Long getApproveUserId() {
        return approveUserId;
    }

    public void setApproveUserId(Long approveUserId) {
        this.approveUserId = approveUserId;
    }

    public String getApproveUserName() {
        return approveUserName;
    }

    public void setApproveUserName(String approveUserName) {
        this.approveUserName = approveUserName;
    }

    public String getApproveUserCode() {
        return approveUserCode;
    }

    public void setApproveUserCode(String approveUserCode) {
        this.approveUserCode = approveUserCode;
    }

    public Date getCommitDate() {
        return commitDate;
    }

    public void setCommitDate(Date commitDate) {
        this.commitDate = commitDate;
    }

    public Date getEffectDate() {
        return effectDate;
    }

    public void setEffectDate(Date effectDate) {
        this.effectDate = effectDate;
    }

    @ReferSerialTransfer(referCode="idm-employee")
    public Long getPurchaseWorkerId() {
        return purchaseWorkerId;
    }
    @ReferDeserialTransfer
    public void setPurchaseWorkerId(Long purchaseWorkerId) {
        this.purchaseWorkerId = purchaseWorkerId;
    }

    public String getPurchaseWorkerName() {
        return purchaseWorkerName;
    }

    public void setPurchaseWorkerName(String purchaseWorkerName) {
        this.purchaseWorkerName = purchaseWorkerName;
    }
    @ReferSerialTransfer(referCode = "support-defdoc")
    public Long getJobSpecialtyId() {
        return jobSpecialtyId;
    }
    @ReferDeserialTransfer
    public void setJobSpecialtyId(Long jobSpecialtyId) {
        this.jobSpecialtyId = jobSpecialtyId;
    }

    public String getJobSpecialtyName() {
        return jobSpecialtyName;
    }

    public void setJobSpecialtyName(String jobSpecialtyName) {
        this.jobSpecialtyName = jobSpecialtyName;
    }

    public Integer getHasNewPropertyVal() {
        return hasNewPropertyVal;
    }

    public void setHasNewPropertyVal(Integer hasNewPropertyVal) {
        this.hasNewPropertyVal = hasNewPropertyVal;
    }

    public Integer getExcessStatus() {
        return excessStatus;
    }

    public void setExcessStatus(Integer excessStatus) {
        this.excessStatus = excessStatus;
    }

    public String getBillStateName() {
        return billStateName;
    }

    public void setBillStateName(String billStateName) {
        this.billStateName = billStateName;
    }

    public String getCommitFlag() {
        return commitFlag;
    }

    public void setCommitFlag(String commitFlag) {
        this.commitFlag = commitFlag;
    }

    @Override
    public String getCreateUserName() {
        return createUserName;
    }

    public void setCreateUserName(String createUserName) {
        this.createUserName = createUserName;
    }

    private List<PurchasePlanDetailVO> detailList = new ArrayList<>(); // 采购计划详情
    @ReferSerialTransfer(referCode="idm-org")
    public Long getOrgId() {
        return orgId;
    }
    @ReferDeserialTransfer
    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }
    @ReferDeserialTransfer
    public Long getParentOrgId() {
        return parentOrgId;
    }

    public void setParentOrgId(Long parentOrgId) {
        this.parentOrgId = parentOrgId;
    }
    public String getParentOrgName() {
        return parentOrgName;
    }

    public void setParentOrgName(String parentOrgName) {
        this.parentOrgName = parentOrgName;
    }
    public String getParentOrgCode() {
        return parentOrgCode;
    }

    public void setParentOrgCode(String parentOrgCode) {
        this.parentOrgCode = parentOrgCode;
    }
    @ReferSerialTransfer(referCode="project-set")
    public Long getProjectId() {
        return projectId;
    }
    @ReferDeserialTransfer
    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public String getProjectCode() {
        return projectCode;
    }

    public void setProjectCode(String projectCode) {
        this.projectCode = projectCode;
    }
    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    @ReferSerialTransfer(referCode="idm-employee")
    public Long getEngineerId() {
        return engineerId;
    }
    @ReferDeserialTransfer
    public void setEngineerId(Long engineerId) {
        this.engineerId = engineerId;
    }
    public String getEngineerName() {
        return engineerName;
    }

    public void setEngineerName(String engineerName) {
        this.engineerName = engineerName;
    }
    public String getEngineerCode() {
        return engineerCode;
    }

    public void setEngineerCode(String engineerCode) {
        this.engineerCode = engineerCode;
    }
    @ReferSerialTransfer(referCode="idm-employee")
    public Long getProjectManagerId() {
        return projectManagerId;
    }
    @ReferDeserialTransfer
    public void setProjectManagerId(Long projectManagerId) {
        this.projectManagerId = projectManagerId;
    }
    public String getProjectManagerName() {
        return projectManagerName;
    }

    public void setProjectManagerName(String projectManagerName) {
        this.projectManagerName = projectManagerName;
    }
    public String getProjectManagerCode() {
        return projectManagerCode;
    }

    public void setProjectManagerCode(String projectManagerCode) {
        this.projectManagerCode = projectManagerCode;
    }
    @ReferSerialTransfer(referCode="idm-employee")
    public Long getChiefEngineerId() {
        return chiefEngineerId;
    }
    @ReferDeserialTransfer
    public void setChiefEngineerId(Long chiefEngineerId) {
        this.chiefEngineerId = chiefEngineerId;
    }
    public String getChiefEngineerName() {
        return chiefEngineerName;
    }

    public void setChiefEngineerName(String chiefEngineerName) {
        this.chiefEngineerName = chiefEngineerName;
    }
    public String getChiefEngineerCode() {
        return chiefEngineerCode;
    }

    public void setChiefEngineerCode(String chiefEngineerCode) {
        this.chiefEngineerCode = chiefEngineerCode;
    }
    public String getPlanName() {
        return planName;
    }

    public void setPlanName(String planName) {
        this.planName = planName;
    }
    public String getCompileName() {
        return compileName;
    }

    public void setCompileName(String compileName) {
        this.compileName = compileName;
    }
    public Integer getExcessFlag() {
        return excessFlag;
    }

    public void setExcessFlag(Integer excessFlag) {
        this.excessFlag = excessFlag;
    }
    public Integer getNewMatFlag() {
        return newMatFlag;
    }

    public void setNewMatFlag(Integer newMatFlag) {
        this.newMatFlag = newMatFlag;
    }
    public Integer getPushStatus() {
        return pushStatus;
    }

    public void setPushStatus(Integer pushStatus) {
        this.pushStatus = pushStatus;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    
     public List<PurchasePlanDetailVO> getDetailList() {
        return detailList;
     }

     public void setDetailList(List<PurchasePlanDetailVO> detailList) {
        this.detailList = detailList;
     }
}
